# Changelog

## [1.3.0](https://github.com/kisiac/kisiac/compare/v1.2.0...v1.3.0) (2025-12-05)


### Features

* specify encryption via mapping ([#10](https://github.com/kisiac/kisiac/issues/10)) ([8682a79](https://github.com/kisiac/kisiac/commit/8682a7991ab71e3133274856b1026e7ab38e68f1))

## [1.2.0](https://github.com/kisiac/kisiac/compare/v1.1.0...v1.2.0) (2025-12-04)


### Features

* allow yte config ([#8](https://github.com/kisiac/kisiac/issues/8)) ([4dda2b4](https://github.com/kisiac/kisiac/commit/4dda2b4160fbbe107d0b4b3a9d185a9c85716d66))

## [1.1.0](https://github.com/kisiac/kisiac/compare/v1.0.4...v1.1.0) (2025-12-04)


### Features

* encryption support ([#7](https://github.com/kisiac/kisiac/issues/7)) ([8340ed6](https://github.com/kisiac/kisiac/commit/8340ed68633597b3658731d700c7ba54d5548c25))


### Bug Fixes

* proper defaults for filesystem spec ([c775169](https://github.com/kisiac/kisiac/commit/c7751696c2c9f1c830ec1677c753db49a9ac93c4))

## [1.0.4](https://github.com/kisiac/kisiac/compare/v1.0.3...v1.0.4) (2025-11-24)


### Bug Fixes

* add license ([c4b4798](https://github.com/kisiac/kisiac/commit/c4b4798f7fde5836bff676c1bdc20b5e41a69ce6))

## [1.0.3](https://github.com/kisiac/kisiac/compare/v1.0.2...v1.0.3) (2025-11-24)


### Documentation

* update cli help ([8a436db](https://github.com/kisiac/kisiac/commit/8a436dbf32a9bb15f0c3a0f222d1240e2a7859af))

## [1.0.2](https://github.com/kisiac/kisiac/compare/v1.0.1...v1.0.2) (2025-11-24)


### Bug Fixes

* use correct package for building ([f91bd42](https://github.com/kisiac/kisiac/commit/f91bd42750005194913938017fc2e10759ef9df9))

## [1.0.1](https://github.com/kisiac/kisiac/compare/v1.0.0...v1.0.1) (2025-11-24)


### Miscellaneous Chores

* release 1.0.0 ([168e6ce](https://github.com/kisiac/kisiac/commit/168e6cecee807f254f8fefefe2bc87f3c48272e2))
* Release 1.0.1 ([a3e7ab2](https://github.com/kisiac/kisiac/commit/a3e7ab2465bbb9a56ad909b3e5b50193fdd355cd))

## 1.0.0 (2025-11-24)


### Miscellaneous Chores

* release 1.0.0 ([168e6ce](https://github.com/koesterlab/kisiac/commit/168e6cecee807f254f8fefefe2bc87f3c48272e2))
